package liquidacion;

public final class Modelo {
	
	/**
	 * Calcula el sueldo imponible segun las horas trabajadas, categoria de trabajador
	 * y nivel de estudios.
	 * @param horas Horas trabajadas
	 * @param trabajador Tipo de Trabajador
	 * @param estudios Nivel de estudios
	 * @return double Sueldo imponible calculado.
	 */
	public double calculaSueldoImponible(int horas, int trabajador, int estudios)
	{
		double sueldo = 0d;
		for (int i = 1; i <= horas; i++)
		{
			if (i <= 30) //Horas normales
				sueldo += 8000d;
			else //Horas extra
				sueldo += 18000d;
		}
		
		double bonifTrab = 0d;
		//Bonificacion segun tipo trabajador
		switch(trabajador)
		{
		case 1: //JUNIOR
			bonifTrab += sueldo*5d/100d;
			break;
		case 2: //SENIOR
			bonifTrab += sueldo*10d/100d;
			break;
		case 3: //MASTER
			bonifTrab += sueldo*15d/100d;
		}
		
		//Bonificacion segun estudios
		double bonifEstud = 0d;
		switch(estudios)
		{
		case 1: //Medio
			bonifEstud = sueldo*3d/100d;
			break;
		case 2: //Tecnico
			bonifEstud = sueldo*5d/100d;
			break;
		case 3: //Profesional
			bonifEstud = sueldo*7d/100d;
		}
		return sueldo + bonifTrab + bonifEstud;
	}
	
	/**
	 * Calcula y proporciona 4 datos:<br>
	 * <ol><li>Descuento AFP</li><li>Descuento destinado a salud</li>
	 * <li>Descuento seguros</li><li>Sueldo liquido</li></ol><br>
	 * Estos 4 datos se retornan juntos en un array de 4 elementos.
	 * @param imponible double Sueldo imponible sobre el que realizar calculos
	 * @return double[] con los 4 datos calculados
	 */
	public double[] calculaDescuentosYLiquido(double imponible)
	{
		
		double[] calculos = new double[4];
		
		//AFP 12%
		calculos[0] = imponible*12d/100d;
		//Salud 7% 
		calculos[1] = imponible*7d/100d;
		//Seguros 2%
		calculos[2] = imponible*2d/100d;
		//Sueldo liquido
		calculos[3] = imponible - (calculos[0] + calculos[1] + calculos[2]);
		
		return calculos;
	}
	

}
