package liquidacion;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Container;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.reflect.InvocationTargetException;

import javax.swing.GroupLayout;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.LayoutStyle;
import javax.swing.SwingUtilities;

import paneles.*;

public final class Vista {
	
	private Controlador controlador;
	private Container contenedor;
	private PanelConTextfield panelRut;
	private PanelConTextfield panelNombre;
	private PanelConTextfield panelHoras;
	private PanelConCombo panelTrabajador;
	private PanelConCombo panelEstudios;
	private PanelSur panelSur;
	private JTextArea areaTexto;
	
	public Vista(Controlador c) {
		controlador = c;
		creaGUI();
	}
	
	private void creaGUI() {
		
		try {
			SwingUtilities.invokeAndWait(new Runnable() {
				@Override
				public void run() {
					contenedor = new Container();
					contenedor.setBackground(new Color(189, 247, 114));
					contenedor.setLayout(new BorderLayout());
					contenedor.add(new PanelNorte(), BorderLayout.NORTH);
										//Panel central
					JPanel centro = new JPanel();
					centro.setBackground(null);
					//Parte izquierda
					MiLabel labelRut = new MiLabel("RUT");
					MiLabel labelNombre = new MiLabel("NOMBRE");
					MiLabel labelHoras = new MiLabel("HORAS TRABAJADAS");
					MiLabel labelTrabajador = new MiLabel("TIPO TRABAJADOR");
					MiLabel labelEstudios = new MiLabel("NIVEL DE ESTUDIOS");
					panelRut = new PanelConTextfield();
					panelNombre = new PanelConTextfield();
					panelHoras = new PanelConTextfield();
					panelTrabajador = new PanelConCombo(new String[]{"Seleccione una opcion", "JUNIOR", "SENIOR", "MASTER"});
					panelEstudios = new PanelConCombo(new String[]{"Seleccione una opcion", "Media", "Tecnico", "Profesional"});
					JPanel izquierda = new JPanel();
					izquierda.setBackground(null);
					GroupLayout layout = new GroupLayout(izquierda);
					izquierda.setLayout(layout);
					layout.setAutoCreateContainerGaps(true);
					layout.setAutoCreateGaps(true);
					layout.setHorizontalGroup(
							layout.createSequentialGroup()
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.TRAILING)
									.addComponent(labelRut).addComponent(labelNombre)
									.addComponent(labelHoras).addComponent(labelTrabajador)
									.addComponent(labelEstudios)
									)
							.addGroup(layout.createParallelGroup()
									.addComponent(panelRut).addComponent(panelNombre)
									.addComponent(panelHoras).addComponent(panelTrabajador)
									.addComponent(panelEstudios)
									)
							);
					layout.setVerticalGroup(layout.createSequentialGroup()
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
									.addComponent(labelRut).addComponent(panelRut))
							.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
									.addComponent(labelNombre).addComponent(panelNombre))
							.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
									.addComponent(labelHoras).addComponent(panelHoras))
							.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
									.addComponent(labelTrabajador).addComponent(panelTrabajador))
							.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
							.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
									.addComponent(labelEstudios).addComponent(panelEstudios))
							.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
							);
					
					
					//Parte derecha
					areaTexto = new JTextArea(10, 18);
					setTextoParaArea("", "", "", "", "", "", "");
					areaTexto.setEditable(false);
					areaTexto.setFont(new Font("Verdana", Font.PLAIN, 16));
					areaTexto.setMargin(new Insets(5, 5, 5, 5));
					//Listo
					centro.add(izquierda);
					centro.add(areaTexto);
					contenedor.add(centro, BorderLayout.CENTER);
					
					//Panel sur con botones
					panelSur = new PanelSur();
					panelSur.generar.addActionListener(new AccionGenerar());
					panelSur.reset.addActionListener(new AccionResetear());
					contenedor.add(panelSur, BorderLayout.SOUTH);
				}
			});
			
		} catch (InvocationTargetException | InterruptedException e) {
			e.printStackTrace();
		}
	}
	
	public Container getContenedor() {
		return contenedor;
	}
	
	private void setTextoParaArea(String nombre, String rut, String sueldoImp, String afp, String salud,
			String bonos, String sueldoLiq) {
		areaTexto.setText(
				String.format("Nombre: %s\nRUT: %s\nSueldo Imponible: %s\n\nAFP: %s\nSALUD: %s\nBONOS: %s\n\nSueldo Liquido:%s",
				nombre, rut, sueldoImp, afp, salud, bonos, sueldoLiq)
				);
	}
	
	private boolean validaDatos() {
		//Comprobamos si campos de texto estan vacios
		if (panelRut.estaVacio() || panelNombre.estaVacio() || panelHoras.estaVacio())
		{
			JOptionPane.showMessageDialog(null, "Faltan datos en los campos de texto", "Validacion de datos",
					JOptionPane.WARNING_MESSAGE);
			return false;
		}
		
		//Comprobamos si en el campo horas trabajadas, tenemos un dato numerico entero
		try {
			Integer.parseInt(panelHoras.getTexto());
		} catch (NumberFormatException e) {
			JOptionPane.showMessageDialog(null, "El campo horas no tiene un valor entero valido", "Validacion de datos",
					JOptionPane.WARNING_MESSAGE);
			return false;
		}
		
		//Comprobamos si los comboBox se ha selecionado alguna opcion
		int trabajador = panelTrabajador.getIndice();
		int estudios = panelEstudios.getIndice();
		if (trabajador == 0)
		{
			JOptionPane.showMessageDialog(null, "Seleccion el Tipo de Trabajador", "Validacion de datos",
					JOptionPane.WARNING_MESSAGE);
			return false;
		}
		if (estudios == 0)
		{
			JOptionPane.showMessageDialog(null, "Seleccion el Nivel de Estudios", "Validacion de datos",
					JOptionPane.WARNING_MESSAGE);
			return false;
		}
		
		//Si hemos llegado hasta aquí, es que los datos son validables
		return true;
	}
	
	private class AccionResetear implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			panelRut.setTexto("");
			panelNombre.setTexto("");
			panelHoras.setTexto("");
			panelTrabajador.reset();
			panelEstudios.reset();
			setTextoParaArea("", "", "", "", "", "", "");
		}
	}
	
	private class AccionGenerar implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			if (validaDatos())
			{
				// Recopilamos datos
				String nombre = panelNombre.getTexto();
				String rut = panelRut.getTexto();
				int horas = Integer.parseInt(panelHoras.getTexto());
				int trabajador = panelTrabajador.getIndice();
				int estudios = panelEstudios.getIndice();
				//Solicitamos calculos al modelo a traves del controlador
				double sueldoImponible = controlador.calculaSueldoImponible(horas, trabajador, estudios);
				double[] descuentosYLiquido = controlador.calculaDescuentosYLiquido(sueldoImponible);
				//Tenemos datos, mostramos en el area texto
				setTextoParaArea(nombre, rut, String.format("%.2f", sueldoImponible),
						String.format("%.2f", descuentosYLiquido[0]), String.format("%.2f", descuentosYLiquido[1]),
						String.format("%.2f", descuentosYLiquido[2]), String.format("%.2f", descuentosYLiquido[3]));
			}
			
		}
	}

}
